@@ -2,10 +2,10 @@
 
 # local
 from .between import between
-from .btc_address import btc_address
 from .card import amex, card_number, diners, discover, jcb, mastercard, unionpay, visa
 from .country import calling_code, country_code, currency
 from .cron import cron
+from .crypto_addresses import btc_address, eth_address
 from .domain import domain
 from .email import email
 from .encoding import base58, base64
@@ -33,13 +33,12 @@ from .url import url
 from .utils import ValidationError, validator
 from .uuid import uuid
 
-# from .crypto_addresses import eth_address
-
 __all__ = (
     # ...
     "between",
     # crypto_addresses
     "btc_address",
+    "eth_address",
     # cards
     "amex",
     "card_number",
@@ -105,4 +104,4 @@ __all__ = (
     "validator",
 )
 
-__version__ = "0.28.3"
+__version__ = "0.29.0"
